==> nodejs_interop-0.5.0.tar.gz: lib/src/js/json.dart <==
part of nodejs_interop.js;

/// Encodes JSON objects to strings and decodes strings to JSON objects.
@JS('JSON')
abstract class Json {

  /// Parses the [source] string and returns the resulting JSON object.
  ///
  /// The optional [reviver] function is called once for each object or list property that has been parsed during decoding.
  /// The `key` argument is either the integer list index for a list property, the string map key for object properties, or `null` for the final result.
  ///
  /// The default [reviver] (when not provided) is the identity function.
  external static dynamic parse(String source, [dynamic reviver(key, value)]);

  /// Converts a [value] to a JSON string.
  ///
  /// The [replacer] parameter can be either a function or a list. As a function, it takes two parameters, the key and the value being stringified.
  /// The object in which the key was found is provided as the replacer's `this` parameter. Initially it gets called with an empty key
  /// representing the object being stringified, and it then gets called for each property on the object or array being stringified.
  /// It should return the value that should be added to the JSON string.
  ///
  /// If [replacer] is a list, the list's values indicate the names of the properties in the object that should be included in the resulting JSON string.
  ///
  /// The [space] argument may be used to control spacing in the final string.
  /// If it is an integer, successive levels in the stringification will each be indented by this many space characters (up to `10`).
  /// If it is a string, successive levels will be indented by this string (or the first ten characters of it).
  external static String stringify(value, [replacer, space]);
}

==> nodejs_interop-0.7.0.tar.gz: lib/src/js/json.dart <==
part of nodejs_interop.js;

/// Encodes JSON objects to strings and decodes strings to JSON objects.
@JS('JSON')
abstract class Json {

  /// Parses the [source] string and returns the resulting JSON object.
  ///
  /// The optional [reviver] function is called once for each object or list property that has been parsed during decoding.
  /// The `key` argument is either the integer list index for a list property, the string map key for object properties, or `null` for the final result.
  ///
  /// The default [reviver] (when not provided) is the identity function.
  external static dynamic parse(String source, [reviver(key, value)]);

  /// Converts a [value] to a JSON string.
  ///
  /// The [replacer] parameter can be either a function or a list. As a function, it takes two parameters, the key and the value being stringified.
  /// The object in which the key was found is provided as the replacer's `this` parameter. Initially it gets called with an empty key
  /// representing the object being stringified, and it then gets called for each property on the object or array being stringified.
  /// It should return the value that should be added to the JSON string.
  ///
  /// If [replacer] is a list, the list's values indicate the names of the properties in the object that should be included in the resulting JSON string.
  ///
  /// The [space] argument may be used to control spacing in the final string.
  /// If it is an integer, successive levels in the stringification will each be indented by this many space characters (up to `10`).
  /// If it is a string, successive levels will be indented by this string (or the first ten characters of it).
  external static String stringify(value, [replacer, space]);
}
